==> eea.cynadmin-1.10.zip: eea.cynadmin-1.10/eea/cynadmin/browser/externaltemplates.py <==
from eea.cynadmin.browser.URLSuckerUTF8 import URLSuck
from Products.CMFCore.utils import getToolByName

from plone.memoize import ram
from plone.app.portlets.cache import render_cachekey

def externalTemplatesBase(context):
    pptool = getToolByName(context,'portal_properties')
    p_external_templates_base = pptool.site_properties.getProperty('externalTemplatesBase')
    if not p_external_templates_base:
        p_external_templates_base = "http://www.eea.europa.eu"
    return p_external_templates_base

def _render_cachekey(method, self, url):
    return url

class ExternalTemplates(object):

    @ram.cache(_render_cachekey)
    def getExternalTemplate(self, url):
        return URLSuck(url, 20)

    def getHeader(self):
        lang = self.request.cookies.get('I18N_LANGUAGE','en')
        lang_str = ''
        if lang not in ['en', 'ar', 'eu', 'ru','en-us']:
            lang_str = '/' + lang
        return self.getExternalTemplate(externalTemplatesBase(self.context)+lang_str+'/getHeader?jsdisable=all')

    def getFooter(self):
        lang = self.request.cookies.get('I18N_LANGUAGE','en')
        lang_str = ''
        if lang not in ['en', 'ar', 'eu', 'ru','en-us']:
            lang_str = '/' + lang
        return self.getExternalTemplate(externalTemplatesBase(self.context)+lang_str+'/getFooter')

    def getRequiredHead(self):
        head = self.getExternalTemplate(externalTemplatesBase(self.context)+'/getRequiredHead?jsdisable=all')
        head = head.replace("<head>","").replace("</head>","")
        return head

    def invalidateCache(self):
        storages = ram.ram.caches.values()
        invalidated = False
        for storage in storages:
            cache = ram.choose_cache(storage)
            statistics = cache.ramcache.getStatistics()
            for stat in statistics:
                if stat.has_key('path'):
                    if stat['path'] == 'eea.cynadmin.browser.externaltemplates.getExternalTemplate':
                        cache.ramcache.invalidateAll()
                        break

        return "done"

==> eea.cynadmin-1.14.zip: eea.cynadmin-1.14/eea/cynadmin/browser/externaltemplates.py <==
from eea.cynadmin.browser.URLSuckerUTF8 import URLSuck
from Products.CMFCore.utils import getToolByName

from plone.memoize import ram
from plone.app.portlets.cache import render_cachekey

def externalTemplatesBase(context):
    pptool = getToolByName(context,'portal_properties')
    p_external_templates_base = pptool.site_properties.getProperty('externalTemplatesBase')
    if not p_external_templates_base:
        p_external_templates_base = "http://www.eea.europa.eu"
    return p_external_templates_base

def _render_cachekey(method, self, url):
    return url

class ExternalTemplates(object):

    @ram.cache(_render_cachekey)
    def getExternalTemplate(self, url):
        template = URLSuck(url, 20)
        template = template.replace("<head>","").replace("</head>","")
        template = template.replace("<html>","").replace("</html>","")
        return template

    def getHeader(self):
        lang = self.request.cookies.get('I18N_LANGUAGE','en')
        lang_str = ''
        if lang not in ['en', 'ar', 'eu', 'ru','en-us']:
            lang_str = '/' + lang
        return self.getExternalTemplate(externalTemplatesBase(self.context)+lang_str+'/getHeader?jsdisable=all')

    def getFooter(self):
        lang = self.request.cookies.get('I18N_LANGUAGE','en')
        lang_str = ''
        if lang not in ['en', 'ar', 'eu', 'ru','en-us']:
            lang_str = '/' + lang
        return self.getExternalTemplate(externalTemplatesBase(self.context)+lang_str+'/getFooter')

    def getRequiredHead(self):
        return self.getExternalTemplate(externalTemplatesBase(self.context)+'/getRequiredHead?jsdisable=all')

    def invalidateCache(self):
        storages = ram.ram.caches.values()
        invalidated = False
        for storage in storages:
            cache = ram.choose_cache(storage)
            statistics = cache.ramcache.getStatistics()
            for stat in statistics:
                if stat.has_key('path'):
                    if stat['path'] == 'eea.cynadmin.browser.externaltemplates.getExternalTemplate':
                        cache.ramcache.invalidateAll()
                        break

        return "done"
